# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.embed
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class VerbDescriptor(object):
    """
    Struct Class

    describes a verb.

    See Also:
        `API VerbDescriptor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1embed_1_1VerbDescriptor.html>`_
    """
    typeName: Literal['com.sun.star.embed.VerbDescriptor']

    def __init__(self, VerbID: typing.Optional[int] = ..., VerbName: typing.Optional[str] = ..., VerbFlags: typing.Optional[int] = ..., VerbAttributes: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            VerbID (int, optional): VerbID value.
            VerbName (str, optional): VerbName value.
            VerbFlags (int, optional): VerbFlags value.
            VerbAttributes (int, optional): VerbAttributes value.
        """


    @property
    def VerbID(self) -> int:
        """
        specifies the id of the verb.
        """


    @property
    def VerbName(self) -> str:
        """
        specifies the name of the verb.
        """


    @property
    def VerbFlags(self) -> int:
        """
        specifies the flags that are set for the verb.
        
        The flags can be used to build the verb's menu.
        """


    @property
    def VerbAttributes(self) -> int:
        """
        specifies the attributes of the verb.
        
        It can take values from VerbAttributes.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.bridge.oleautomation
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class Decimal(object):
    """
    Struct Class

    is the UNO representation of the Automation type DECIMAL.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API Decimal <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1Decimal.html>`_
    """
    typeName: Literal['com.sun.star.bridge.oleautomation.Decimal']

    def __init__(self, Scale: typing.Optional[int] = ..., Sign: typing.Optional[int] = ..., LowValue: typing.Optional[int] = ..., MiddleValue: typing.Optional[int] = ..., HighValue: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Scale (int, optional): Scale value.
            Sign (int, optional): Sign value.
            LowValue (int, optional): LowValue value.
            MiddleValue (int, optional): MiddleValue value.
            HighValue (int, optional): HighValue value.
        """


    @property
    def Scale(self) -> int:
        """
        corresponds to DECIMAL.scale.
        """


    @property
    def Sign(self) -> int:
        """
        corresponds to DECIMAL.sign.
        """


    @property
    def LowValue(self) -> int:
        """
        corresponds to DECIMAL.Lo32.
        """


    @property
    def MiddleValue(self) -> int:
        """
        corresponds to DECIMAL.Mid32.
        """


    @property
    def HighValue(self) -> int:
        """
        corresponds to DECIMAL.Hi32.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_content_event_listener import XContentEventListener as XContentEventListener_18ea0ebd
    from .x_content_identifier import XContentIdentifier as XContentIdentifier_edc90d78

class XContent(XInterface_8f010a43):
    """
    specifies a content with a type and an identifier, which is able to manage listeners for events that are related to contents.

    See Also:
        `API XContent <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XContent.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XContent']

    def addContentEventListener(self, Listener: 'XContentEventListener_18ea0ebd') -> None:
        """
        adds a listener for content events.
        """
    def getContentType(self) -> str:
        """
        returns a type string, which is unique for that type of content (e.g.
        
        \"application/vnd.sun.star.hierarchy-folder\").
        """
    def getIdentifier(self) -> 'XContentIdentifier_edc90d78':
        """
        returns the identifier of the content.
        """
    def removeContentEventListener(self, Listener: 'XContentEventListener_18ea0ebd') -> None:
        """
        removes a listener for content events.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rendering
from typing_extensions import Literal


class BlendMode(object):
    """
    Const

    These constants determine some extra ways how the primitive color is combined with the background.
    
    Please refer to the PDF specification for explanations of this constants.

    See Also:
        `API BlendMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1BlendMode.html>`_
    """
    NORMAL: Literal[0]
    MULTIPLY: Literal[1]
    SCREEN: Literal[2]
    OVERLAY: Literal[3]
    DARKEN: Literal[4]
    LIGHTEN: Literal[5]
    COLOR_DODGE: Literal[6]
    COLOR_BURN: Literal[7]
    HARD_LIGHT: Literal[8]
    SOFT_LIGHT: Literal[9]
    DIFFERENCE: Literal[10]
    EXCLUSION: Literal[11]
    HUE: Literal[12]
    SATURATION: Literal[13]
    COLOR: Literal[14]
    LUMINOSITY: Literal[15]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .general_function import GeneralFunction as GeneralFunction_e2280d25


class SubTotalColumn(object):
    """
    Struct Class

    describes how a single data column is treated when creating subtotals.

    See Also:
        `API SubTotalColumn <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1SubTotalColumn.html>`_
    """
    typeName: Literal['com.sun.star.sheet.SubTotalColumn']

    def __init__(self, Column: typing.Optional[int] = ..., Function: typing.Optional[GeneralFunction_e2280d25] = ...) -> None:
        """
        Constructor

        Arguments:
            Column (int, optional): Column value.
            Function (GeneralFunction, optional): Function value.
        """


    @property
    def Column(self) -> int:
        """
        the index of the column inside the source data area.
        """


    @property
    def Function(self) -> GeneralFunction_e2280d25:
        """
        specifies what kind of subtotals are calculated.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ui
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d

class XModuleUIConfigurationManager(XInterface_8f010a43):
    """
    specifies specific functions of a module based user interface configuration manager interface.
    
    A module user interface configuration manager supports, unlike a document based ui configuration manager, two layers of configuration settings data:
    
    **since**
    
        OOo 2.0

    See Also:
        `API XModuleUIConfigurationManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.XModuleUIConfigurationManager']

    def getDefaultSettings(self, ResourceURL: str) -> 'XIndexAccess_f0910d6d':
        """
        retrieves the settings from the default layer of the user interface configuration manager if it has a default layer.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def isDefaultSettings(self, ResourceURL: str) -> bool:
        """
        determine if the settings of a user interface element is part of the default layer of the user interface configuration manager.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal


class UserDataPart(object):
    """
    Const

    These constants define which part of the user data is displayed in a user data text field (service \"sun.one.text.TextField.ExtendedUser\")

    See Also:
        `API UserDataPart <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html>`_
    """
    COMPANY: Literal[0]
    """
    The field shows the company name.
    """
    FIRSTNAME: Literal[1]
    """
    The field shows the first name.
    """
    NAME: Literal[2]
    """
    The field shows the name.
    """
    SHORTCUT: Literal[3]
    """
    The field shows the initials.
    """
    STREET: Literal[4]
    """
    The field shows the street.
    """
    COUNTRY: Literal[5]
    """
    The field shows the country.
    """
    ZIP: Literal[6]
    """
    The field shows the zip code.
    """
    CITY: Literal[7]
    """
    The field shows the city.
    """
    TITLE: Literal[8]
    """
    The field shows the title.
    """
    POSITION: Literal[9]
    """
    The field shows the position.
    """
    PHONE_PRIVATE: Literal[10]
    """
    The field shows the no of the private phone.
    """
    PHONE_COMPANY: Literal[11]
    """
    The field shows the number of the business phone.
    """
    FAX: Literal[12]
    """
    The field shows the fax no.
    """
    EMAIL: Literal[13]
    """
    The field shows the e-Mail.
    """
    STATE: Literal[14]
    """
    The field shows the state.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xml.sax
from typing_extensions import Literal
import typing
from .x_fast_context_handler import XFastContextHandler as XFastContextHandler_361e0f5c
if typing.TYPE_CHECKING:
    from ...awt.point import Point as Point_5fb2085e
    from ...beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ...document.x_document_properties import XDocumentProperties as XDocumentProperties_4c31102b
    from ...drawing.x_draw_page import XDrawPage as XDrawPage_b07a0b57
    from ...drawing.x_shape import XShape as XShape_8fd00a3d
    from ...frame.x_model import XModel as XModel_7a6e095c
    from ...graphic.x_graphic_mapper import XGraphicMapper as XGraphicMapper_eec10d61

class XFastShapeContextHandler(XFastContextHandler_361e0f5c):
    """
    receives notification of sax document events from a XFastParser.
    
    **since**
    
        LibreOffice 7.1

    See Also:
        `API XFastShapeContextHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XFastShapeContextHandler.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.sax.XFastShapeContextHandler']

    def setGraphicMapper(self, xGraphicMapper: 'XGraphicMapper_eec10d61') -> None:
        """
        Graphic mapper to map a key/id string to a XGraphic.
        
        This is needed to remember for XGraphics for a path in the document storage
        
        **since**
        
            LibreOffice 7.1
        """
    @property
    def MediaDescriptor(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        """

    @property
    def DocumentProperties(self) -> 'XDocumentProperties_4c31102b':
        """
        """

    @property
    def DrawPage(self) -> 'XDrawPage_b07a0b57':
        """
        """

    @property
    def Model(self) -> 'XModel_7a6e095c':
        """
        """

    @property
    def Position(self) -> 'Point_5fb2085e':
        """
        """

    @property
    def RelationFragmentPath(self) -> str:
        """
        """

    @property
    def Shape(self) -> 'XShape_8fd00a3d':
        """
        """

    @property
    def StartToken(self) -> int:
        """
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class SystemPointer(object):
    """
    Const

    specifies the shape of a mouse pointer.

    See Also:
        `API SystemPointer <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1SystemPointer.html>`_
    """
    ARROW: Literal[0]
    """
    specifies the normal arrow-like mouse pointer.
    """
    INVISIBLE: Literal[1]
    """
    specifies an invisible mouse pointer.
    """
    WAIT: Literal[2]
    """
    specifies a waiting symbol as a mouse pointer (for example hourglass).
    """
    TEXT: Literal[3]
    """
    specifies a mouse pointer for text (cursor-like).
    """
    HELP: Literal[4]
    """
    specifies a mouse pointer for on-line help.
    """
    CROSS: Literal[5]
    """
    specifies a cross as a mouse pointer.
    """
    MOVE: Literal[6]
    """
    specifies a mouse pointer which symbolizes movement.
    """
    NSIZE: Literal[7]
    """
    specifies a mouse pointer which symbolizes resizing for a top border.
    """
    SSIZE: Literal[8]
    """
    specifies a mouse pointer which symbolizes resizing for a bottom border.
    """
    WSIZE: Literal[9]
    """
    specifies a mouse pointer which symbolizes resizing for a left border.
    """
    ESIZE: Literal[10]
    """
    specifies a mouse pointer which symbolizes resizing for a right border.
    """
    NWSIZE: Literal[11]
    """
    specifies a mouse pointer which symbolizes resizing for the top-left corner.
    """
    NESIZE: Literal[12]
    """
    specifies a mouse pointer which symbolizes resizing for the top-right corner.
    """
    SWSIZE: Literal[13]
    """
    specifies a mouse pointer which symbolizes resizing for the bottom-left corner.
    """
    SESIZE: Literal[14]
    """
    specifies a mouse pointer which symbolizes resizing for the bottom-right corner.
    """
    WINDOW_NSIZE: Literal[15]
    """
    specifies a mouse pointer which symbolizes window resizing for a top border.
    """
    WINDOW_SSIZE: Literal[16]
    """
    specifies a mouse pointer which symbolizes window resizing for a bottom border.
    """
    WINDOW_WSIZE: Literal[17]
    """
    specifies a mouse pointer which symbolizes window resizing for a left border.
    """
    WINDOW_ESIZE: Literal[18]
    """
    specifies a mouse pointer which symbolizes window resizing for a right border.
    """
    WINDOW_NWSIZE: Literal[19]
    """
    specifies a mouse pointer which symbolizes window resizing for the top-left corner.
    """
    WINDOW_NESIZE: Literal[20]
    """
    specifies a mouse pointer which symbolizes window resizing for the top-right corner.
    """
    WINDOW_SWSIZE: Literal[21]
    """
    specifies a mouse pointer which symbolizes window resizing for the bottom-left corner.
    """
    WINDOW_SESIZE: Literal[22]
    """
    specifies a mouse pointer which symbolizes window resizing for the bottom-right corner.
    """
    HSPLIT: Literal[23]
    """
    specifies a mouse pointer which symbolizes horizontal splitting.
    """
    VSPLIT: Literal[24]
    """
    specifies a mouse pointer which symbolizes vertical splitting.
    """
    HSIZEBAR: Literal[25]
    """
    specifies a mouse pointer which symbolizes horizontal resizing.
    """
    VSIZEBAR: Literal[26]
    """
    specifies a mouse pointer which symbolizes vertical resizing.
    """
    HAND: Literal[27]
    """
    specifies a hand symbol as mouse pointer.
    """
    REFHAND: Literal[28]
    """
    specifies a pointing hand symbol as mouse pointer.
    """
    PEN: Literal[29]
    """
    specifies a pen symbol as mouse pointer.
    """
    MAGNIFY: Literal[30]
    """
    specifies a magnify symbol as mouse pointer.
    """
    FILL: Literal[31]
    """
    specifies a fill symbol as mouse pointer.
    """
    ROTATE: Literal[32]
    """
    specifies a rotate symbol as mouse pointer.
    """
    HSHEAR: Literal[33]
    """
    specifies a horizontal shear symbol as mouse pointer.
    """
    VSHEAR: Literal[34]
    """
    specifies a vertical shear symbol as mouse pointer.
    """
    MIRROR: Literal[35]
    """
    specifies a mirror symbol as mouse pointer.
    """
    CROOK: Literal[36]
    """
    specifies a crook symbol as mouse pointer.
    """
    CROP: Literal[37]
    """
    specifies a crop symbol as mouse pointer.
    """
    MOVEPOINT: Literal[38]
    """
    specifies a mouse pointer which symbolizes moving a point.
    """
    MOVEBEZIERWEIGHT: Literal[39]
    """
    specifies a mouse pointer which symbolizes moving a Bezier weight.
    """
    MOVEDATA: Literal[40]
    """
    specifies a mouse pointer which symbolizes moving data.
    """
    COPYDATA: Literal[41]
    """
    specifies a mouse pointer which symbolizes copying data.
    """
    LINKDATA: Literal[42]
    """
    specifies a mouse pointer which symbolizes linking data.
    """
    MOVEDATALINK: Literal[43]
    """
    specifies a mouse pointer which symbolizes moving a data link.
    """
    COPYDATALINK: Literal[44]
    """
    specifies a mouse pointer which symbolizes copying a data link.
    """
    MOVEFILE: Literal[45]
    """
    specifies a mouse pointer which symbolizes moving a file.
    """
    COPYFILE: Literal[46]
    """
    specifies a mouse pointer which symbolizes copying a file.
    """
    LINKFILE: Literal[47]
    """
    specifies a mouse pointer which symbolizes linking a file.
    """
    MOVEFILELINK: Literal[48]
    """
    specifies a mouse pointer which symbolizes moving a file link.
    """
    COPYFILELINK: Literal[49]
    """
    specifies a mouse pointer which symbolizes copying a file link.
    """
    MOVEFILES: Literal[50]
    """
    specifies a mouse pointer which symbolizes moving multiple files.
    """
    COPYFILES: Literal[51]
    """
    specifies a mouse pointer which symbolizes copying multiple files.
    """
    NOTALLOWED: Literal[52]
    """
    specifies a mouse pointer which symbolizes \"not allowed\".
    """
    DRAW_LINE: Literal[53]
    """
    specifies a mouse pointer which symbolizes drawing a line.
    """
    DRAW_RECT: Literal[54]
    """
    specifies a mouse pointer which symbolizes drawing a rectangle.
    """
    DRAW_POLYGON: Literal[55]
    """
    specifies a mouse pointer which symbolizes drawing a polygon.
    """
    DRAW_BEZIER: Literal[56]
    """
    specifies a mouse pointer which symbolizes drawing a Bezier.
    """
    DRAW_ARC: Literal[57]
    """
    specifies a mouse pointer which symbolizes drawing an arc.
    """
    DRAW_PIE: Literal[58]
    """
    specifies a mouse pointer which symbolizes drawing a pie.
    """
    DRAW_CIRCLECUT: Literal[59]
    """
    specifies a mouse pointer which symbolizes drawing a circle cut.
    """
    DRAW_ELLIPSE: Literal[60]
    """
    specifies a mouse pointer which symbolizes drawing an ellipse.
    """
    DRAW_FREEHAND: Literal[61]
    """
    specifies a mouse pointer which symbolizes drawing free handed.
    """
    DRAW_CONNECT: Literal[62]
    """
    specifies a mouse pointer which symbolizes drawing a connector.
    """
    DRAW_TEXT: Literal[63]
    """
    specifies a mouse pointer which symbolizes drawing text.
    """
    DRAW_CAPTION: Literal[64]
    """
    specifies a mouse pointer which symbolizes drawing a text caption.
    """
    CHART: Literal[65]
    """
    specifies a mouse pointer which symbolizes a chart.
    """
    DETECTIVE: Literal[66]
    """
    specifies a mouse pointer which symbolizes a detective.
    """
    PIVOT_COL: Literal[67]
    """
    specifies a mouse pointer which symbolizes a pivot column.
    """
    PIVOT_ROW: Literal[68]
    """
    specifies a mouse pointer which symbolizes a pivot row.
    """
    PIVOT_FIELD: Literal[69]
    """
    specifies a mouse pointer which symbolizes a pivot field.
    """
    CHAIN: Literal[70]
    """
    specifies a mouse pointer which symbolizes a chain.
    """
    CHAIN_NOTALLOWED: Literal[71]
    """
    specifies a mouse pointer which symbolizes \"chaining not allowed\".
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.connection
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class SocketPermission(object):
    """
    Struct Class

    This permission represents access to a network via sockets.
    
    A SocketPermission consists of a host specification and a set of actions specifying ways to connect to that host. The host is specified as
    
    The host is expressed as a DNS name, as a numerical IP address, or as \"localhost\" (for the local machine). The wildcard \"*\" may be included once in a DNS name host specification. If it is included, it must be in the leftmost position, as in \"*.sun.com\".
    The port or portrange is optional. A port specification of the form \"N-\", where N is a port number, signifies all ports numbered N and above, while a specification of the form \"-N\" indicates all ports numbered N and below.
    
    The possible ways to connect to the host are
    
    The \"listen\" action is only meaningful when used with \"localhost\". The \"resolve\" (resolve host/ip name service lookups) action is implied when any of the other actions are present.
    As an example of the creation and meaning of SocketPermissions, note that if the following permission
    
    is granted, it allows to connect to port 7777 on foo.bar.com, and to accept connections on that port.
    Similarly, if the following permission
    
    is granted, it allows that code to accept connections on, connect to, or listen on any port between 1024 and 65535 on the local host.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API SocketPermission <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1connection_1_1SocketPermission.html>`_
    """
    typeName: Literal['com.sun.star.connection.SocketPermission']

    def __init__(self, Host: typing.Optional[str] = ..., Actions: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Host (str, optional): Host value.
            Actions (str, optional): Actions value.
        """


    @property
    def Host(self) -> str:
        """
        target host with optional portrange
        """


    @property
    def Actions(self) -> str:
        """
        comma separated actions list
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration
from .hierarchy_access import HierarchyAccess as HierarchyAccess_5e871071
from .property_hierarchy import PropertyHierarchy as PropertyHierarchy_83841184

class GroupAccess(HierarchyAccess_5e871071, PropertyHierarchy_83841184):
    """
    Service Class

    provides access to a predefined heterogeneous group of values and nested trees as part of a hierarchy.
    
    Provides access to, and information about, its children and descendants viewed either as properties or as contained elements.
    
    Groups are static collections within the hierarchy.
    
    The number and names of contained elements are fixed in advance and each child may have a different type.
    
    This service subsumes two alternate ways of accessing child and descendent elements. These strongly overlap, supporting the basic identity xGroup.getPropertyValue( aName ) == xGroup.getByName( aName ).

    See Also:
        `API GroupAccess <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1GroupAccess.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal
"""
Const

constants representing a single dictionary-list event.

These flags define the possible types for a dictionary-list event.

See Also:
    `API DictionaryListEventFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1linguistic2_1_1DictionaryListEventFlags.html>`_
"""
ADD_POS_ENTRY: Literal[1]
"""
A positive entry was added to a dictionary from the dictionary list.
"""
DEL_POS_ENTRY: Literal[2]
"""
A positive entry was deleted from a dictionary of the dictionary-list or a dictionary with positive entries was cleared.
"""
ADD_NEG_ENTRY: Literal[4]
"""
A negative entry was added to a dictionary from the dictionary-list.
"""
DEL_NEG_ENTRY: Literal[8]
"""
A negative entry was deleted from a dictionary of the dictionary-list or a dictionary with negative entries was cleared.
"""
ACTIVATE_POS_DIC: Literal[16]
"""
A dictionary with positive entries was activated or has changed its language.
"""
DEACTIVATE_POS_DIC: Literal[32]
"""
A dictionary with positive entries was deactivated or has changed its language.
"""
ACTIVATE_NEG_DIC: Literal[64]
"""
A dictionary with negative entries was activated or has changed its language.
"""
DEACTIVATE_NEG_DIC: Literal[128]
"""
A dictionary with negative entries was deactivated or has changed its language.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
from .x_top_window import XTopWindow as XTopWindow_8ebb0a57

class XTopWindow2(XTopWindow_8ebb0a57):
    """
    extends XTopWindow with additional functionality

    See Also:
        `API XTopWindow2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindow2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XTopWindow2']

    @property
    def Display(self) -> int:
        """
        controls on which display the window is shown.
        
        When retrieving this property, in case the window is positioned on multiple displays, the number returned will be of the display containing the upper left pixel of the frame area (that is of the client area on system decorated windows, or the frame area of undecorated resp. owner decorated windows).
        """

    @property
    def IsMaximized(self) -> bool:
        """
        controls whether the window is currently maximized
        """

    @property
    def IsMinimized(self) -> bool:
        """
        controls whether the window is currently minimized
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .text_column import TextColumn as TextColumn_9b3f0ae0

class XTextColumns(XInterface_8f010a43):
    """
    manages columns within the object.
    
    The values used are relative. So it is not necessary to know the width of the object. The sum of the relative width values depends on the object and is defined in \"ReferenceValue.\"

    See Also:
        `API XTextColumns <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XTextColumns.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.text.XTextColumns']

    def getColumnCount(self) -> int:
        """
        """
    def getColumns(self) -> 'typing.Tuple[TextColumn_9b3f0ae0, ...]':
        """
        returns the column description of the object.
        """
    def getReferenceValue(self) -> int:
        """
        As described above, the width values are relative.
        """
    def setColumnCount(self, nColumns: int) -> None:
        """
        sets the number of columns.
        
        The minimum is 1 column.
        """
    def setColumns(self, Columns: 'typing.Tuple[TextColumn_9b3f0ae0, ...]') -> None:
        """
        sets the descriptors of all columns.
        
        The number of members in the sequence must be the same as the number of columns of the object.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class FetchResult(object):
    """
    Struct Class

    contains data of several rows of a ContentResultSet.
    
    This struct is returned from XFetchProvider.fetch(), for example.

    See Also:
        `API FetchResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1FetchResult.html>`_
    """
    typeName: Literal['com.sun.star.ucb.FetchResult']

    def __init__(self, Rows: typing.Optional[typing.Tuple[object, ...]] = ..., StartIndex: typing.Optional[int] = ..., Orientation: typing.Optional[bool] = ..., FetchError: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Rows (typing.Tuple[object, ...], optional): Rows value.
            StartIndex (int, optional): StartIndex value.
            Orientation (bool, optional): Orientation value.
            FetchError (int, optional): FetchError value.
        """


    @property
    def Rows(self) -> typing.Tuple[object, ...]:
        """
        contains the demanded data.
        
        One any contains the data of one whole row. Those methods which use this struct have to specify, what the any has to contain.
        """


    @property
    def StartIndex(self) -> int:
        """
        indicates the index of the first row contained in FetchResult.Rows in the original result set.
        
        So if FetchResult.StartIndex equals 3, the first element in the sequence FetchResult.Rows contains the data of the index 3 in the original result set.
        
        The following rows are one after the other, but the direction depends on the value of FetchResult.Direction
        """


    @property
    def Orientation(self) -> bool:
        """
        indicates the orientation in which the rows are fetched and set into the sequence FetchResult.Rows.
        
        When FetchResult.Orientation equals TRUE, the rows in FetchResult.Rows are ordered in the same way as in the original result set.
        """


    @property
    def FetchError(self) -> int:
        """
        indicates whether and which error has occurred, while fetching.
        
        The value may contain zero or more constants of the FetchError constants group.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .animation_attributes import AnimationAttributes as AnimationAttributes_5c8f108d
    from .view_state import ViewState as ViewState_cab30c62
    from .x_canvas import XCanvas as XCanvas_b19b0b7a

class XAnimation(XInterface_8f010a43):
    """
    This interface defines an animation sequence.
    
    This interface must be implemented by every animation object. It is used by the XCanvas interface to render generic animations.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XAnimation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimation.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rendering.XAnimation']

    def getAnimationAttributes(self) -> 'AnimationAttributes_5c8f108d':
        """
        Request the attribute information for this animation.
        
        This method returns the AnimationAttributes structure, which defines more closely how to play this animation.
        """
    def render(self, canvas: 'XCanvas_b19b0b7a', viewState: 'ViewState_cab30c62', t: float) -> None:
        """
        Render the animation content at time t into the specified canvas.
        
        Note that it is perfectly legal to e.g. map t in a nonlinear fashion to internal frames, for example to achieve acceleration or deceleration effects. It is required that the render method has const semantics, i.e. when called with the same parameter set, identical output must be generated. This is because e.g. a Sprite might decide arbitrarily to render an animation once and cache the result, or repaint it via XAnimation.render every time.
        
        The rendered content, although, must be exactly the same for identical viewState, canvas and t values. Or, for that matters, must call the same canvas methods in the same order with the same parameter sets, for identical viewState and t values. Furthermore, when viewState has the identity transformation set, rendered output must be contained in a rectangle with upper left corner at (0,0) and width and height given by the AnimationAttributes' untransformedSize member. Any content exceeding this box might get clipped off.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_accessible_key_binding import XAccessibleKeyBinding as XAccessibleKeyBinding_c493129a

class XAccessibleAction(XInterface_8f010a43):
    """
    Implement this interface to give access to actions that can be executed for accessible objects.
    
    Every accessible object that can be manipulated beyond its methods exported over the accessibility API should support this interface to expose all actions that it can perform. Each action can be performed or be queried for a description or associated key bindings.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleAction <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleAction.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleAction']

    def doAccessibleAction(self, nIndex: int) -> bool:
        """
        Perform the specified Action on the object.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getAccessibleActionCount(self) -> int:
        """
        Returns the number of accessible actions available in this object.
        
        If there are more than one, the first one is considered the \"default\" action of the object.
        """
    def getAccessibleActionDescription(self, nIndex: int) -> str:
        """
        Returns a description of the specified action of the object.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getAccessibleActionKeyBinding(self, nIndex: int) -> 'XAccessibleKeyBinding_c493129a':
        """
        Returns a key binding object, if there is one, associated with the specified action.
        
        Note that there can be several alternative key bindings for an action. See XAccessibleKeyBinding for more information about how key bindings are represented.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xml.csax
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .xml_attribute import XMLAttribute as XMLAttribute_df0f0cdb

class XCompressedDocumentHandler(XInterface_8f010a43):
    """
    A compressed XDocumentHandler interface.
    
    All methods in this interface have the same function with methods in the XDocumentHandler interface.
    
    Because there is no interface parameter in these methods, so using this interface to transfer SAX event is thought to have better performance than using the XDocumentHandler interface, in case of when UNO C++/Java bridge is involved.

    See Also:
        `API XCompressedDocumentHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1csax_1_1XCompressedDocumentHandler.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.csax.XCompressedDocumentHandler']

    def compressedCharacters(self, aChars: str) -> None:
        """

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def compressedEndDocument(self) -> None:
        """

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def compressedEndElement(self, aName: str) -> None:
        """

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def compressedIgnorableWhitespace(self, aWhitespaces: str) -> None:
        """

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def compressedProcessingInstruction(self, aTarget: str, aData: str) -> None:
        """

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def compressedSetDocumentLocator(self, columnNumber: int, lineNumber: int, publicId: str, systemId: str) -> None:
        """

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def compressedStartDocument(self) -> None:
        """

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
    def compressedStartElement(self, aName: str, aAttributes: 'typing.Tuple[XMLAttribute_df0f0cdb, ...]') -> None:
        """

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API OutgoingMessageState <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#a8dec3ee1933cc93724b3764b124b8cc1>`_
"""

COMPLETELY_LOCALLY_SENT: 'uno.Enum'
"""
Message has been sent upstream to all recipients.
"""
CONFIRMED: 'uno.Enum'
"""
Recipient confirmed reading.
"""
EXTERNAL_ERROR: 'uno.Enum'
"""
Global fatal error (e.g.

last member in SMTP chain could not deliver the message).
"""
NONRECOVERABLE_LOCAL_ERROR: 'uno.Enum'
"""
Local fatal error (e.g.

first SMTP server upstream did not accept the message).
"""
PARTIALLY_LOCALLY_SENT: 'uno.Enum'
"""
Message has been sent upstream to some recipients.
"""
RECOVERABLE_LOCAL_ERROR: 'uno.Enum'
"""
Local, non-fatal error (e.g.

network temporarily not available).
"""
WAITING_CONFIRMATION: 'uno.Enum'
"""
Message was sent; we are waiting for confirmation.
"""
WRITTEN: 'uno.Enum'
"""
Message has just been placed into the out tray.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..sdbc.x_prepared_statement import XPreparedStatement as XPreparedStatement_fbc80de4

class XCommandPreparation(XInterface_8f010a43):
    """
    is used for preparation of commands.
    
    A command could be a table, query, or any kind of SQL statement prepared by the user.

    See Also:
        `API XCommandPreparation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XCommandPreparation.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.XCommandPreparation']

    def prepareCommand(self, command: str, commandType: int) -> 'XPreparedStatement_fbc80de4':
        """
        creates a com.sun.star.sdbc.PreparedStatement object for sending parameterized SQL statements to the database.
        
        A SQL statement with or without IN parameters can be pre-compiled and stored in a PreparedStatement object. This object can then be used to efficiently execute this statement multiple times.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.security
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API ExtAltNameType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1security.html#a5c5a31742567126d2ba88393b05efa3f>`_
"""

DIRECTORY_NAME: 'uno.Enum'
"""
Currently unsupported.
"""
DNS_NAME: 'uno.Enum'
"""
The entry contains a dns name.

The value of CertAltNameEntry contains a OUString.
"""
EDI_PARTY_NAME: 'uno.Enum'
"""
Currently unsupported.
"""
IP_ADDRESS: 'uno.Enum'
"""
The entry contains an IP address.

The value of CertAltNameEntry contains a Sequence of sal_Int8.
"""
OTHER_NAME: 'uno.Enum'
"""
Customize name/value pair The value of CertAltNameEntry contains a NamedValue.
"""
REGISTERED_ID: 'uno.Enum'
"""
The entry contains a registered id.

The value of CertAltNameEntry contains a OUString.
"""
RFC822_NAME: 'uno.Enum'
"""
The entry contains rfc822 name.

The value of CertAltNameEntry contains an OUString.
"""
URL: 'uno.Enum'
"""
The entry contains a URL.

The value of CertAltNameEntry contains a OUString.
"""
X400_ADDRESS: 'uno.Enum'
"""
Currently unsupported.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text.textfield
from typing_extensions import Literal
"""
Const

Text field types.

Right now this only contains the types that are supported by the edit engine, but it should eventually contain all field types that are used across all engines.

**since**

    LibreOffice 3.6

See Also:
    `API Type <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Type.html>`_
"""
UNSPECIFIED: Literal[-1]
DATE: Literal[0]
URL: Literal[1]
PAGE: Literal[2]
PAGES: Literal[3]
TIME: Literal[4]
TABLE: Literal[5]
EXTENDED_TIME: Literal[6]
EXTENDED_FILE: Literal[7]
AUTHOR: Literal[8]
MEASURE: Literal[9]
DOCINFO_TITLE: Literal[10]
PRESENTATION_HEADER: Literal[11]
PRESENTATION_FOOTER: Literal[12]
PRESENTATION_DATE_TIME: Literal[13]
PAGE_NAME: Literal[14]
DOCINFO_CUSTOM: Literal[15]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt.tree
from typing_extensions import Literal
from abc import ABC

class XTreeNode(ABC):
    """
    An instance implementing this interface represents the model data for an entry in a XTreeDataModel.
    
    The TreeControl uses this interface to retrieve the model information needed to display a hierarchical outline
    
    Each XTreeNode in a XTreeDataModel must be unique.

    See Also:
        `API XTreeNode <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeNode.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.tree.XTreeNode']

    def getChildAt(self, Index: int) -> 'XTreeNode':
        """
        Returns the child tree node at Index.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getChildCount(self) -> int:
        """
        Returns the number of child nodes.
        """
    def getCollapsedGraphicURL(self) -> str:
        """
        The URL for a graphic that is rendered to visualize collapsed non leaf nodes.
        
        If URL is empty, XTreeControl.DefaultCollapsedGraphicURL is used.
        """
    def getDisplayValue(self) -> object:
        """
        If not empty, the textual representation of this any is used as the text part of this node.
        """
    def getExpandedGraphicURL(self) -> str:
        """
        The URL for a graphic that is rendered to visualize expanded non leaf nodes.
        
        If URL is empty, XTreeControl.DefaultExpandedGraphicURL is used.
        """
    def getIndex(self, Node: 'XTreeNode') -> int:
        """
        Returns the index of Node in this instances children.
        """
    def getNodeGraphicURL(self) -> str:
        """
        The URL for a graphic that is rendered before the text part of this node.
        
        If this URL is empty, no graphic is rendered.
        """
    def getParent(self) -> 'XTreeNode':
        """
        Returns the parent node of this node.
        """
    def hasChildrenOnDemand(self) -> bool:
        """
        Returns TRUE if the children of this node are created on demand.
        
        A TreeControl will handle a node that returns TRUE always like a node that has child nodes, even if getChildCount() returns 0.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.inspection
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .property_category_descriptor import PropertyCategoryDescriptor as PropertyCategoryDescriptor_f4691406

class XObjectInspectorModel(ABC):
    """
    describes the model of an ObjectInspector
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API XObjectInspectorModel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1inspection_1_1XObjectInspectorModel.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.inspection.XObjectInspectorModel']

    def describeCategories(self) -> 'typing.Tuple[PropertyCategoryDescriptor_f4691406, ...]':
        """
        describes the property categories used by the property handlers.
        
        Properties can be sorted into different categories, described by the LineDescriptor.Category attribute, which is filled in XPropertyHandler.describePropertyLine() method of your property handler.
        Those names provided by the handlers are programmatic names. All other information about categories is part of the PropertyCategoryDescriptor, and describeCategories() assembles information about all categories which all property handlers provided by the model use.
        """
    def getPropertyOrderIndex(self, PropertyName: str) -> int:
        """
        retrieves an index in a global property ordering, for a given property name
        
        In the user interface of an ObjectInspector, single properties are represented by single lines, and those lines are displayed successively. To determine an order of the property lines, the inspector model can associate an \"order index\" with each property. The ObjectInspector will then sort the property lines in a way that they have the same relative ordering as the \"order indexes\" of their properties.
        
        Note that the concrete value the model returns for a given property does not matter. All what matters is that if you want a certain property Foo to be displayed after another property Bar, then the order index of Foo should be greater than the order index of Bar.
        
        If for two different properties the same order index is returned, the ObjectInspector will assume the order in which those properties were provided by the respective property handler (XPropertyHandler.getSupportedProperties()).
        If two such properties originate from different handlers, they will be ordered according to the order of the handlers, as provided in the HandlerFactories attribute.
        """
    @property
    def HandlerFactories(self) -> 'typing.Tuple[object, ...]':
        """
        describes a set of factories for creating XPropertyHandlers
        
        Every element of the sequence must contain information to create a XPropertyHandler instance. Two ways are currently supported:
        
        This attribute is usually only evaluated by the ObjectInspector instance which the model is currently bound to.
        
        The order of factories is important: If two property handlers declare themselves responsible for the same property, the one whose factory is listed last wins. Also, if a handler B wants to supersede a property of another handler A, A's factory must precede the factory of B.
        """

    @property
    def HasHelpSection(self) -> bool:
        """
        indicates that the object inspector should have a help section.
        
        The object inspector displays lines of property/values, optionally grouped into categories, as described by the property handlers.
        Additionally, the inspector can optionally display a section dedicated to help texts. Clients could use this section to display context-sensitive help, for instance short texts explaining the currently selected property.
        
        **since**
        
            OOo 2.2
        """

    @property
    def IsReadOnly(self) -> bool:
        """
        determines whether the object inspector's UI should be read-only.
        
        In this case, the user is able to browse through all properties, but cannot change any of them.
        
        In a read-only object inspector, the property controls are readonly or disabled themselves, and the primary and secondary buttons of a property line are both disabled.
        """

    @property
    def MaxHelpTextLines(self) -> int:
        """
        denotes the maximum number of lines of text to be reserved for the help section.
        
        This property is ignored by the ObjectInspector if HasHelpSection is FALSE.
        
        The layout of the ObjectInspector is undefined if MaxHelpTextLines is smaller than MinHelpTextLines.
        
        **since**
        
            OOo 2.2
        """

    @property
    def MinHelpTextLines(self) -> int:
        """
        denotes the minimum number of lines of text to be reserved for the help section.
        
        This property is ignored by the ObjectInspector if HasHelpSection is FALSE.
        
        The layout of the ObjectInspector is undefined if MinHelpTextLines is larger than MaxHelpTextLines.
        
        **since**
        
            OOo 2.2
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.mail
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_authenticator import XAuthenticator as XAuthenticator_c7b50c5e
    from .x_connection_listener import XConnectionListener as XConnectionListener_aaa0e59
    from ..uno.x_current_context import XCurrentContext as XCurrentContext_c9110c7a

class XMailService(XInterface_8f010a43):
    """
    Represents a mail server abstraction.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XMailService <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1mail_1_1XMailService.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.mail.XMailService']

    def addConnectionListener(self, xListener: 'XConnectionListener_aaa0e59') -> None:
        """
        Register a connection listener.
        """
    def connect(self, xConnectionContext: 'XCurrentContext_c9110c7a', xAuthenticator: 'XAuthenticator_c7b50c5e') -> None:
        """
        Connect to a mail service.
        
        Only one connection to a mail service can be established at a time.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.AlreadyConnectedException: ``AlreadyConnectedException``
            com.sun.star.io.UnknownHostException: ``UnknownHostException``
            com.sun.star.io.NoRouteToHostException: ``NoRouteToHostException``
            com.sun.star.io.ConnectException: ``ConnectException``
            com.sun.star.auth.AuthenticationFailedException: ``AuthenticationFailedException``
            com.sun.star.mail.MailException: ``MailException``
        """
    def disconnect(self) -> None:
        """
        Disconnect from a mail service.

        Raises:
            com.sun.star.mail.MailException: ``MailException``
        """
    def getCurrentConnectionContext(self) -> 'XCurrentContext_c9110c7a':
        """
        Return the context of the current connection.
        
        The context contains information like the server name, port, connection type etc.

        Raises:
            com.sun.star.io.NotConnectedException: ``NotConnectedException``
        """
    def getSupportedConnectionTypes(self) -> 'typing.Tuple[str, ...]':
        """
        Returns all connection types which are supported to connect to the mail service.
        
        At least support insecure connections must be supported. Currently defined connection types are (the values should be handled case insensitive): \"Insecure\" - insecure connections \"SSL\" - Secure Socket Layer 2.0/3.0 based connection
        """
    def isConnected(self) -> bool:
        """
        Returns whether a connection to a mail service currently exist or not.
        """
    def removeConnectionListener(self, xListener: 'XConnectionListener_aaa0e59') -> None:
        """
        Unregister a connection listener.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_content import XContent as XContent_79db0975
    from .x_content_identifier import XContentIdentifier as XContentIdentifier_edc90d78

class XContentAccess(XInterface_8f010a43):
    """
    specifies methods for obtaining information on a content in different levels.
    
    For example, if there is a cursor which points to XContents, this interface could be used to give the user access to the content under the cursor. If the client only needs the identifier string of the content, there is no need to first create the content object, then to obtain the string from it and after that to release the content.

    See Also:
        `API XContentAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XContentAccess.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XContentAccess']

    def queryContent(self) -> 'XContent_79db0975':
        """
        returns the content ( \"most expensive method\" ).
        """
    def queryContentIdentifier(self) -> 'XContentIdentifier_edc90d78':
        """
        returns the identifier object of the content.
        """
    def queryContentIdentifierString(self) -> str:
        """
        returns the identifier string of the content ( \"cheap method\" ).
        
        Note that this string can be used later to recreate the content.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.task
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XStatusIndicator(XInterface_8f010a43):
    """
    controls a status indicator which displays progress of longer actions to the user
    
    Such objects are provided by a XStatusIndicatorFactory.

    See Also:
        `API XStatusIndicator <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1task_1_1XStatusIndicator.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.task.XStatusIndicator']

    def end(self) -> None:
        """
        stop the progress
        
        Further calls of XStatusIndicator.setText(), XStatusIndicator.setValue() or XStatusIndicator.reset() must be ignored. Only XStatusIndicator.start() can reactivate this indicator. It's not allowed to destruct the indicator inside this method. The instance must be gone by using ref count or disposing.
        """
    def reset(self) -> None:
        """
        clear progress value and description
        
        Calling of setValue(0) and setText(\"\") should do the same. Stopped indicators must ignore this call.
        """
    def setText(self, Text: str) -> None:
        """
        update progress description
        
        Initial value can be set during starting of the progress by calling XStatusIndicator.start(). Stopped indicators must ignore this call.
        """
    def setValue(self, Value: int) -> None:
        """
        update progress value
        
        Wrong values must be ignored and stopped indicators must ignore this call generally.
        """
    def start(self, Text: str, Range: int) -> None:
        """
        initialize and start the progress
        
        It activates a new created or reactivate an already used indicator (must be finished by calling XStatusIndicator.end() before!). By the way it's possible to set first progress description and the possible range of progress value. That means that a progress can runs from 0 to Range.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from .x_property_set_registry import XPropertySetRegistry as XPropertySetRegistry_c2e0e84

class XPersistentPropertySet(XPropertySet_bc180bfa):
    """
    A persistent property set, which can be saved in and restored from a XPropertySetRegistry.

    See Also:
        `API XPersistentPropertySet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XPersistentPropertySet.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XPersistentPropertySet']

    def getKey(self) -> str:
        """
        returns the key used to address the set in the property set registry.
        """
    def getRegistry(self) -> 'XPropertySetRegistry_c2e0e84':
        """
        returns the registry used to store the property set.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ..._pyi.awt.grid.default_grid_column_model import DefaultGridColumnModel as DefaultGridColumnModel
from ..._pyi.awt.grid.default_grid_data_model import DefaultGridDataModel as DefaultGridDataModel
from ..._pyi.awt.grid.grid_column import GridColumn as GridColumn
from ..._pyi.awt.grid.grid_column_event import GridColumnEvent as GridColumnEvent
from ..._pyi.awt.grid.grid_data_event import GridDataEvent as GridDataEvent
from ..._pyi.awt.grid.grid_invalid_data_exception import GridInvalidDataException as GridInvalidDataException
from ..._pyi.awt.grid.grid_invalid_model_exception import GridInvalidModelException as GridInvalidModelException
from ..._pyi.awt.grid.grid_selection_event import GridSelectionEvent as GridSelectionEvent
from ..._pyi.awt.grid.sortable_grid_data_model import SortableGridDataModel as SortableGridDataModel
from ..._pyi.awt.grid.uno_control_grid import UnoControlGrid as UnoControlGrid
from ..._pyi.awt.grid.uno_control_grid_model import UnoControlGridModel as UnoControlGridModel
from ..._pyi.awt.grid.x_grid_column import XGridColumn as XGridColumn
from ..._pyi.awt.grid.x_grid_column_listener import XGridColumnListener as XGridColumnListener
from ..._pyi.awt.grid.x_grid_column_model import XGridColumnModel as XGridColumnModel
from ..._pyi.awt.grid.x_grid_control import XGridControl as XGridControl
from ..._pyi.awt.grid.x_grid_data_listener import XGridDataListener as XGridDataListener
from ..._pyi.awt.grid.x_grid_data_model import XGridDataModel as XGridDataModel
from ..._pyi.awt.grid.x_grid_row_selection import XGridRowSelection as XGridRowSelection
from ..._pyi.awt.grid.x_grid_selection_listener import XGridSelectionListener as XGridSelectionListener
from ..._pyi.awt.grid.x_mutable_grid_data_model import XMutableGridDataModel as XMutableGridDataModel
from ..._pyi.awt.grid.x_sortable_grid_data import XSortableGridData as XSortableGridData
from ..._pyi.awt.grid.x_sortable_mutable_grid_data_model import XSortableMutableGridDataModel as XSortableMutableGridDataModel



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.2
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .rectangle import Rectangle as Rectangle_84b109e9


class PaintEvent(EventObject_a3d70b03):
    """
    Struct Class

    specifies the paint event for a component.
    
    This event is a special type which is used to ensure that paint/update method calls are serialized along with the other events delivered from the event queue.

    See Also:
        `API PaintEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1PaintEvent.html>`_
    """
    typeName: Literal['com.sun.star.awt.PaintEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., UpdateRect: typing.Optional[Rectangle_84b109e9] = ..., Count: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            UpdateRect (Rectangle, optional): UpdateRect value.
            Count (int, optional): Count value.
        """


    @property
    def UpdateRect(self) -> Rectangle_84b109e9:
        """
        contains the rectangle area which needs to be repainted.
        """


    @property
    def Count(self) -> int:
        """
        contains the number of paint events that follows this event if it is a multiple PaintEvent.
        
        You can collect the PaintEvent until Count is zero.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.beans
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_property_change_listener import XPropertyChangeListener as XPropertyChangeListener_58e4105a
    from .x_property_set_info import XPropertySetInfo as XPropertySetInfo_efa90d86
    from .x_vetoable_change_listener import XVetoableChangeListener as XVetoableChangeListener_55a41027

class XPropertySet(XInterface_8f010a43):
    """
    provides information about and access to the properties from an implementation.
    
    There are three types of properties:
    
    You can listen to changes of bound properties with the XPropertyChangeListener and you can veto changes of constrained properties with the XVetoableChangeListener.
    
    To implement inaccurate name access, you must support the interface XExactName.

    See Also:
        `API XPropertySet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XPropertySet.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.beans.XPropertySet']

    def addPropertyChangeListener(self, aPropertyName: str, xListener: 'XPropertyChangeListener_58e4105a') -> None:
        """
        adds an XPropertyChangeListener to the specified property.
        
        An empty name (\"\") registers the listener to all bound properties. If the property is not bound, the behavior is not specified.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def addVetoableChangeListener(self, PropertyName: str, aListener: 'XVetoableChangeListener_55a41027') -> None:
        """
        adds an XVetoableChangeListener to the specified property with the name PropertyName.
        
        An empty name (\"\") registers the listener to all constrained properties. If the property is not constrained, the behavior is not specified.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def getPropertySetInfo(self) -> 'XPropertySetInfo_efa90d86':
        """
        """
    def getPropertyValue(self, PropertyName: str) -> object:
        """

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def removePropertyChangeListener(self, aPropertyName: str, aListener: 'XPropertyChangeListener_58e4105a') -> None:
        """
        removes an XPropertyChangeListener from the listener list.
        
        It is a \"noop\" if the listener is not registered.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def removeVetoableChangeListener(self, PropertyName: str, aListener: 'XVetoableChangeListener_55a41027') -> None:
        """
        removes an XVetoableChangeListener from the listener list.
        
        It is a \"noop\" if the listener is not registered.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def setPropertyValue(self, aPropertyName: str, aValue: object) -> None:
        """
        sets the value of the property with the specified name.
        
        If it is a bound property the value will be changed before the change event is fired. If it is a constrained property a vetoable event is fired before the property value can be changed.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.registry
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .registry_key_type import RegistryKeyType as RegistryKeyType_11940ea5
    from .registry_value_type import RegistryValueType as RegistryValueType_30390f79

class XRegistryKey(XInterface_8f010a43):
    """
    makes structural information (except regarding tree structures) of a single registry key accessible.
    
    This is the main interface for registry keys.

    See Also:
        `API XRegistryKey <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.registry.XRegistryKey']

    def closeKey(self) -> None:
        """
        closes a key in the registry.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def createKey(self, aKeyName: str) -> 'XRegistryKey':
        """
        creates a new key in the registry.
        
        If the key already exists, the function will open the key.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def createLink(self, aLinkName: str, aLinkTarget: str) -> bool:
        """
        creates a new link in the registry.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def deleteKey(self, rKeyName: str) -> None:
        """
        deletes a key from the registry.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def deleteLink(self, rLinkName: str) -> None:
        """
        deletes a link from the registry.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def getAsciiListValue(self) -> 'typing.Tuple[str, ...]':
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
            com.sun.star.registry.InvalidValueException: ``InvalidValueException``
        """
    def getAsciiValue(self) -> str:
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
            com.sun.star.registry.InvalidValueException: ``InvalidValueException``
        """
    def getBinaryValue(self) -> 'typing.Tuple[int, ...]':
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
            com.sun.star.registry.InvalidValueException: ``InvalidValueException``
        """
    def getKeyNames(self) -> 'typing.Tuple[str, ...]':
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def getKeyType(self, rKeyName: str) -> 'RegistryKeyType_11940ea5':
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def getLinkTarget(self, rLinkName: str) -> str:
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def getLongListValue(self) -> 'typing.Tuple[int, ...]':
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
            com.sun.star.registry.InvalidValueException: ``InvalidValueException``
        """
    def getLongValue(self) -> int:
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
            com.sun.star.registry.InvalidValueException: ``InvalidValueException``
        """
    def getResolvedName(self, aKeyName: str) -> str:
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def getStringListValue(self) -> 'typing.Tuple[str, ...]':
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
            com.sun.star.registry.InvalidValueException: ``InvalidValueException``
        """
    def getStringValue(self) -> str:
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
            com.sun.star.registry.InvalidValueException: ``InvalidValueException``
        """
    def getValueType(self) -> 'RegistryValueType_30390f79':
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def isReadOnly(self) -> bool:
        """
        checks if the key can be overwritten.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def isValid(self) -> bool:
        """
        checks if the key points to an open valid key in the data-source.
        """
    def openKey(self, aKeyName: str) -> 'XRegistryKey':
        """
        opens a sub key of the key.
        
        If the sub key does not exist, the function returns a NULL-interface.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def openKeys(self) -> 'typing.Tuple[XRegistryKey, ...]':
        """
        opens all subkeys of the key.
        
        If a subkey is a link, the link will be resolved and the appropriate key will be opened.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def setAsciiListValue(self, seqValue: 'typing.Tuple[str, ...]') -> None:
        """
        sets an ASCII string list value to the key.
        
        The high byte of the string should be NULL. If not, there is no guarantee that the string will be correctly transported. If the key already has a value, the value will be overridden.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def setAsciiValue(self, value: str) -> None:
        """
        sets an ASCII string value to the key.
        
        The high byte of the string should be NULL. If not, there is no guarantee that the string will be correctly transported. If the key already has a value, the value will be overridden.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def setBinaryValue(self, value: 'typing.Tuple[int, ...]') -> None:
        """
        sets a binary value to the key.
        
        If the key already has a value, the value will be overridden.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def setLongListValue(self, seqValue: 'typing.Tuple[int, ...]') -> None:
        """
        sets a long list value to the key.
        
        If the key already has a value, the value will be overridden.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def setLongValue(self, value: int) -> None:
        """
        sets a long value to the key.
        
        If the key already has a value, the value will be overridden.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def setStringListValue(self, seqValue: 'typing.Tuple[str, ...]') -> None:
        """
        sets a unicode string value to the key.
        
        If the key already has a value, the value will be overridden.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    def setStringValue(self, value: str) -> None:
        """
        sets a unicode string value to the key.
        
        If the key already has a value, the value will be overridden.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
    @property
    def KeyName(self) -> str:
        """
        This is the key of the entry relative to its parent.
        
        The access path starts with the root \"/\" and all parent entry names are delimited with slashes \"/\" too, like in a UNIX (R) file system. Slashes which are part of single names are represented as hexadecimals preceded with a \"%\" like in URL syntax.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ui.dialogs
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ...awt.x_window import XWindow as XWindow_713b0924
    from .x_wizard_page import XWizardPage as XWizardPage_ed7c0d3d

class XWizardController(ABC):
    """
    is the interface of a client-provided controller of a custom Wizard.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XWizardController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XWizardController.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.dialogs.XWizardController']

    def canAdvance(self) -> bool:
        """
        """
    def confirmFinish(self) -> bool:
        """
        called when the wizard is about to be finished.
        
        This method allows the controller to do any final checks, and ultimately veto finishing the wizard.
        """
    def createPage(self, ParentWindow: 'XWindow_713b0924', PageId: int) -> 'XWizardPage_ed7c0d3d':
        """
        creates a page
        
        Wizard pages are created on demand, when the respective page is reached during traveling through the wizard. Effectively, this means the method is called at most once for each possible page ID.
        """
    def getPageTitle(self, PageId: int) -> str:
        """
        provides the title of a page given by ID
        
        The page titles are displayed in the wizard's roadmap.
        """
    def onActivatePage(self, PageId: int) -> None:
        """
        called when a new page in the wizard is being activated
        """
    def onDeactivatePage(self, PageId: int) -> None:
        """
        called when a page in the wizard is being deactivated
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class CellProtection(object):
    """
    Struct Class

    describes the kind of protection for a protectable cell.

    See Also:
        `API CellProtection <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1CellProtection.html>`_
    """
    typeName: Literal['com.sun.star.util.CellProtection']

    def __init__(self, IsLocked: typing.Optional[bool] = ..., IsFormulaHidden: typing.Optional[bool] = ..., IsHidden: typing.Optional[bool] = ..., IsPrintHidden: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            IsLocked (bool, optional): IsLocked value.
            IsFormulaHidden (bool, optional): IsFormulaHidden value.
            IsHidden (bool, optional): IsHidden value.
            IsPrintHidden (bool, optional): IsPrintHidden value.
        """


    @property
    def IsLocked(self) -> bool:
        """
        specifies if the cell is locked from modifications by the user.
        """


    @property
    def IsFormulaHidden(self) -> bool:
        """
        specifies if the formula is hidden from the user.
        """


    @property
    def IsHidden(self) -> bool:
        """
        specifies if the cell is hidden from the user.
        """


    @property
    def IsPrintHidden(self) -> bool:
        """
        specifies if the cell is hidden on printouts.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.script
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .all_event_object import AllEventObject as AllEventObject_e2c20d0f

class XAllListener(XEventListener_c7230c4a):
    """
    specifies a listener combining all methods of a listener interface in a single generic call.
    
    Without any output parameters, it is possible to adapt any interface if the XAllListenerAdapterService can generate an adapter.

    See Also:
        `API XAllListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XAllListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.script.XAllListener']

    def approveFiring(self, aEvent: 'AllEventObject_e2c20d0f') -> object:
        """
        gets called when a \"vetoable event\" occurs at the object.
        
        That happens when the listener method raises an exception, or has a return value declared.

        Raises:
            com.sun.star.reflection.InvocationTargetException: ``InvocationTargetException``
        """
    def firing(self, iaEvent: 'AllEventObject_e2c20d0f') -> None:
        """
        gets called when an event occurs at the object.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ui.dialogs
from typing_extensions import Literal
import typing
from ...lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ...awt.x_window import XWindow as XWindow_713b0924

class XWizardPage(XComponent_98dc0ab5):
    """
    is a single page of a Wizard
    
    **since**
    
        OOo 3.3

    See Also:
        `API XWizardPage <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XWizardPage.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.dialogs.XWizardPage']

    def activatePage(self) -> None:
        """
        called when the page is activated
        """
    def canAdvance(self) -> bool:
        """
        determines whether it is allowed to travel to a later page in the wizard
        
        You should base this decision on the state of the page only, not on a global state of the wizard. Usually, you return FALSE here if and only if not all necessary input on the page has been provided by the user, or the provided input is not valid.
        
        If checked for validity is expensive, or if you prefer giving your user more detailed feedback on validity than a disabled Next button in the wizard, then move your checks to the commitPage() method.
        """
    def commitPage(self, Reason: int) -> bool:
        """
        is called when the page is about to be left
        
        An implementation can veto the leave by returning FALSE here. Usually, the decision about this depends on the current state of the page.
        """
    @property
    def PageId(self) -> int:
        """
        denotes the ID of the page.
        
        Within a wizard, no two pages are allowed to have the same ID.
        """

    @property
    def Window(self) -> 'XWindow_713b0924':
        """
        provides read-only access to the window of the page
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.geometry
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .real_point2_d import RealPoint2D as RealPoint2D_d6e70c78


class EllipticalArc(object):
    """
    Struct Class

    This structure specifies an arbitrary elliptical arc.
    
    This structure contains all parameters necessary to specify arbitrary elliptical arcs. The parameters are modeled closely after the SVG specification.
    
    As with the parameters below, there are mostly four different ellipses arcs (two different ellipses, on which four different arcs connect start and end point) which satisfy the given set of constrains. Thus, there are two flags indicating which one of those ellipses should be taken.
    
    **since**
    
        OOo 2.0

    See Also:
        `API EllipticalArc <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1geometry_1_1EllipticalArc.html>`_
    """
    typeName: Literal['com.sun.star.geometry.EllipticalArc']

    def __init__(self, StartPosition: typing.Optional[RealPoint2D_d6e70c78] = ..., EndPosition: typing.Optional[RealPoint2D_d6e70c78] = ..., RadiusX: typing.Optional[float] = ..., RadiusY: typing.Optional[float] = ..., XAxisRotation: typing.Optional[float] = ..., IsLargeArc: typing.Optional[bool] = ..., IsClockwiseSweep: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            StartPosition (RealPoint2D, optional): StartPosition value.
            EndPosition (RealPoint2D, optional): EndPosition value.
            RadiusX (float, optional): RadiusX value.
            RadiusY (float, optional): RadiusY value.
            XAxisRotation (float, optional): XAxisRotation value.
            IsLargeArc (bool, optional): IsLargeArc value.
            IsClockwiseSweep (bool, optional): IsClockwiseSweep value.
        """


    @property
    def StartPosition(self) -> RealPoint2D_d6e70c78:
        """
        Start point of the arc.
        """


    @property
    def EndPosition(self) -> RealPoint2D_d6e70c78:
        """
        End point of the arc.
        """


    @property
    def RadiusX(self) -> float:
        """
        Main radius in x direction of the ellipse this arc is part of.
        """


    @property
    def RadiusY(self) -> float:
        """
        Main radius in y direction of the ellipse this arc is part of.
        """


    @property
    def XAxisRotation(self) -> float:
        """
        Rotation angle of the x axis of the ellipse relative to the x axis of the reference coordinate system.
        """


    @property
    def IsLargeArc(self) -> bool:
        """
        If TRUE, and there's a choice, take the longer one of two arcs connecting start and end point.
        """


    @property
    def IsClockwiseSweep(self) -> bool:
        """
        If TRUE, and there's a choice, take the arc that goes clock-wise from start to end point.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.style
from .paragraph_properties import ParagraphProperties as ParagraphProperties_1e240efc
from .style import Style as Style_7336094a
from ..xml.para_user_defined_attributes_supplier import ParaUserDefinedAttributesSupplier as ParaUserDefinedAttributesSupplier_e8be13a6

class ParagraphStyle(ParagraphProperties_1e240efc, Style_7336094a, ParaUserDefinedAttributesSupplier_e8be13a6):
    """
    Service Class

    specifies a style sheet for paragraphs within a com.sun.star.text.Text.

    See Also:
        `API ParagraphStyle <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html>`_
    """
    @property
    def Category(self) -> int:
        """
        determines the category of a paragraph style.
        """
    @property
    def CharDiffHeight(self) -> float:
        """
        """
    @property
    def CharDiffHeightAsian(self) -> float:
        """
        This value contains the character height as difference in point to the height of the character in the parent style in Asian text.
        """
    @property
    def CharDiffHeightComplex(self) -> float:
        """
        This value contains the character height as difference in point to the height of the character in the parent style in complex text.
        """
    @property
    def CharPropHeight(self) -> int:
        """
        This value contains the character height as percentage value relative to the height of the character in the parent style.
        """
    @property
    def CharPropHeightAsian(self) -> int:
        """
        This value contains the character height as percentage value relative to the height of the character in the parent style in Asian text.
        """
    @property
    def CharPropHeightComplex(self) -> int:
        """
        This value contains the character height as percentage value relative to the height of the character in the parent style in complex text.
        """
    @property
    def PageStyleName(self) -> str:
        """
        returns the name of the page style in use
        
        For setting the page style you have to use the com.sun.star.text.PageDescName properties.
        """
    @property
    def ParaBottomMarginRelative(self) -> int:
        """
        determines the Bottom margin of the paragraph relative to the ParaBottomMargin of the parent style.
        
        If the value of ParaBottomMarginRelative is 100 the current ParaBottomMargin value is used.
        """
    @property
    def ParaLeftMarginRelative(self) -> int:
        """
        determines the left margin of the paragraph relative to the ParaLeftMargin of the parent style.
        
        If the value of ParaLeftMarginRelative is 100 the current ParaLeftMargin value is used.
        """
    @property
    def ParaRightMarginRelative(self) -> int:
        """
        determines the right margin of the paragraph relative to the ParaRightMargin of the parent style.
        
        If the value of ParaRightMarginRelative is 100 the current ParaRightMargin value is used.
        """
    @property
    def ParaTopMarginRelative(self) -> int:
        """
        determines the top margin of the paragraph relative to the ParaTopMargin of the parent style.
        
        If the value of ParaTopMarginRelative is 100 the current ParaTopMargin value is used.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.bridge
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6

class OleObjectFactory(XMultiServiceFactory_191e0eb6):
    """
    Service Class

    makes it possible to create COM objects as UNO objects.
    
    A COM object must have a ProgId since the ProgId is used as argument for XMultiServiceFactory.createInstance. The only interfaces which are mapped are IUnknown and IDispatch. The created UNO objects support com.sun.star.script.XInvocation if the original COM objects support IDispatch.
    
    The optional parameters of the method com.sun.star.lang.XMultiServiceFactory.createInstanceWithArguments() are reserved for future use; at this time they are ignored.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API OleObjectFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1bridge_1_1OleObjectFactory.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.rendering.argb_color import ARGBColor as ARGBColor
from .._pyi.rendering.animation_attributes import AnimationAttributes as AnimationAttributes
from .._pyi.rendering.bitmap_canvas import BitmapCanvas as BitmapCanvas
from .._pyi.rendering.canvas import Canvas as Canvas
from .._pyi.rendering.canvas_factory import CanvasFactory as CanvasFactory
from .._pyi.rendering.caret import Caret as Caret
from .._pyi.rendering.color import Color as Color
from .._pyi.rendering.color_component import ColorComponent as ColorComponent
from .._pyi.rendering.color_profile import ColorProfile as ColorProfile
from .._pyi.rendering.floating_point_bitmap_layout import FloatingPointBitmapLayout as FloatingPointBitmapLayout
from .._pyi.rendering.font_info import FontInfo as FontInfo
from .._pyi.rendering.font_metrics import FontMetrics as FontMetrics
from .._pyi.rendering.font_request import FontRequest as FontRequest
from .._pyi.rendering.integer_bitmap_layout import IntegerBitmapLayout as IntegerBitmapLayout
from .._pyi.rendering.mtf_renderer import MtfRenderer as MtfRenderer
from .._pyi.rendering.panose import Panose as Panose
from .._pyi.rendering.rgb_color import RGBColor as RGBColor
from .._pyi.rendering.render_state import RenderState as RenderState
from .._pyi.rendering.string_context import StringContext as StringContext
from .._pyi.rendering.stroke_attributes import StrokeAttributes as StrokeAttributes
from .._pyi.rendering.text_hit import TextHit as TextHit
from .._pyi.rendering.texture import Texture as Texture
from .._pyi.rendering.view_state import ViewState as ViewState
from .._pyi.rendering.volatile_content_destroyed_exception import VolatileContentDestroyedException as VolatileContentDestroyedException
from .._pyi.rendering.x_animated_sprite import XAnimatedSprite as XAnimatedSprite
from .._pyi.rendering.x_animation import XAnimation as XAnimation
from .._pyi.rendering.x_bezier_poly_polygon2_d import XBezierPolyPolygon2D as XBezierPolyPolygon2D
from .._pyi.rendering.x_bitmap import XBitmap as XBitmap
from .._pyi.rendering.x_bitmap_canvas import XBitmapCanvas as XBitmapCanvas
from .._pyi.rendering.x_bitmap_palette import XBitmapPalette as XBitmapPalette
from .._pyi.rendering.x_buffer_controller import XBufferController as XBufferController
from .._pyi.rendering.x_cached_primitive import XCachedPrimitive as XCachedPrimitive
from .._pyi.rendering.x_canvas import XCanvas as XCanvas
from .._pyi.rendering.x_canvas_font import XCanvasFont as XCanvasFont
from .._pyi.rendering.x_color_space import XColorSpace as XColorSpace
from .._pyi.rendering.x_custom_sprite import XCustomSprite as XCustomSprite
from .._pyi.rendering.x_graphic_device import XGraphicDevice as XGraphicDevice
from .._pyi.rendering.x_half_float_bitmap import XHalfFloatBitmap as XHalfFloatBitmap
from .._pyi.rendering.x_half_float_read_only_bitmap import XHalfFloatReadOnlyBitmap as XHalfFloatReadOnlyBitmap
from .._pyi.rendering.x_ieee_double_bitmap import XIeeeDoubleBitmap as XIeeeDoubleBitmap
from .._pyi.rendering.x_ieee_double_read_only_bitmap import XIeeeDoubleReadOnlyBitmap as XIeeeDoubleReadOnlyBitmap
from .._pyi.rendering.x_ieee_float_bitmap import XIeeeFloatBitmap as XIeeeFloatBitmap
from .._pyi.rendering.x_ieee_float_read_only_bitmap import XIeeeFloatReadOnlyBitmap as XIeeeFloatReadOnlyBitmap
from .._pyi.rendering.x_integer_bitmap import XIntegerBitmap as XIntegerBitmap
from .._pyi.rendering.x_integer_bitmap_color_space import XIntegerBitmapColorSpace as XIntegerBitmapColorSpace
from .._pyi.rendering.x_integer_read_only_bitmap import XIntegerReadOnlyBitmap as XIntegerReadOnlyBitmap
from .._pyi.rendering.x_line_poly_polygon2_d import XLinePolyPolygon2D as XLinePolyPolygon2D
from .._pyi.rendering.x_mtf_renderer import XMtfRenderer as XMtfRenderer
from .._pyi.rendering.x_parametric_poly_polygon2_d import XParametricPolyPolygon2D as XParametricPolyPolygon2D
from .._pyi.rendering.x_poly_polygon2_d import XPolyPolygon2D as XPolyPolygon2D
from .._pyi.rendering.x_simple_canvas import XSimpleCanvas as XSimpleCanvas
from .._pyi.rendering.x_sprite import XSprite as XSprite
from .._pyi.rendering.x_sprite_canvas import XSpriteCanvas as XSpriteCanvas
from .._pyi.rendering.x_text_layout import XTextLayout as XTextLayout
from .._pyi.rendering.x_volatile_bitmap import XVolatileBitmap as XVolatileBitmap



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from ..awt.x_window import XWindow as XWindow_713b0924
    from ..rendering.x_bitmap import XBitmap as XBitmap_b1b70b7b
    from ..rendering.x_canvas import XCanvas as XCanvas_b19b0b7a
    from ..rendering.x_sprite_canvas import XSpriteCanvas as XSpriteCanvas_ff8b0df1

class XPresenterHelper(ABC):
    """
    This interface is a collection of functions that were necessary to implement larger parts of the presenter screen as extension.
    
    The methods of this interface give access to services that could only be implemented in the Office core, not in an extension.
    
    As the presenter screen is no extension any more, this hack can go again; it just needs clean-up.

    See Also:
        `API XPresenterHelper <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XPresenterHelper.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.drawing.XPresenterHelper']

    def captureMouse(self, xWindow: 'XWindow_713b0924') -> None:
        """
        Capture the mouse so that no other window will receive mouse events.
        
        Note that this is a potentially dangerous method. Not calling releaseMouse eventually can lead to an unresponsive application.
        """
    def createCanvas(self, xWindow: 'XWindow_713b0924', nRequestedCanvasFeatureList: int, sOptionalCanvasServiceName: str) -> 'XCanvas_b19b0b7a':
        """
        Create a new canvas for the given window.
        """
    def createSharedCanvas(self, xUpdateCanvas: 'XSpriteCanvas_ff8b0df1', xUpdateWindow: 'XWindow_713b0924', xSharedCanvas: 'XCanvas_b19b0b7a', xSharedWindow: 'XWindow_713b0924', xWindow: 'XWindow_713b0924') -> 'XCanvas_b19b0b7a':
        """
        Create a new canvas for the given window.
        
        The new canvas is a wrapper around the given shared canvas. The wrapper only modifies the origin in all output and clipping methods.
        """
    def createWindow(self, xParentWindow: 'XWindow_713b0924', bCreateSystemChildWindow: bool, bInitiallyVisible: bool, bEnableChildTransparentMode: bool, bEnableParentClip: bool) -> 'XWindow_713b0924':
        """
        Create a new window as child window of the given parent window.
        """
    def getWindowExtentsRelative(self, xChildWindow: 'XWindow_713b0924', xParentWindow: 'XWindow_713b0924') -> 'Rectangle_84b109e9':
        """
        Return the bounding box of the given child window relative to the direct or indirect parent window.
        """
    def loadBitmap(self, id: str, xCanvas: 'XCanvas_b19b0b7a') -> 'XBitmap_b1b70b7b':
        """
        Load a bitmap with a given ID.
        """
    def releaseMouse(self, xWindow: 'XWindow_713b0924') -> None:
        """
        Release a previously captured mouse.
        """
    def toTop(self, xWindow: 'XWindow_713b0924') -> None:
        """
        Move the specified window to the top of its stacking order.
        
        As a result the window will be painted over all its overlapping siblings.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.deployment
from typing_extensions import Literal
import typing
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3
    from .x_package import XPackage as XPackage_cb1f0c4d
    from .x_package_type_info import XPackageTypeInfo as XPackageTypeInfo_3bc70f7b
    from ..task.x_abort_channel import XAbortChannel as XAbortChannel_baca0bc4
    from ..ucb.x_command_environment import XCommandEnvironment as XCommandEnvironment_fb330dee

class XExtensionManager(XComponent_98dc0ab5, XModifyBroadcaster_fd990df0):
    """
    The XExtensionManager interface is used to manage extensions in the user, shared and bundled repository.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XExtensionManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.deployment.XExtensionManager']

    def addExtension(self, url: str, properties: 'typing.Tuple[NamedValue_a37a0af3, ...]', repository: str, xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> 'XPackage_cb1f0c4d':
        """
        adds an extension.
        
        The properties argument is currently only used to suppress the license information for shared extensions.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def checkPrerequisitesAndEnable(self, extension: 'XPackage_cb1f0c4d', xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> int:
        """
        check if all prerequisites for the extension are fulfilled and activates it, if possible.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def createAbortChannel(self) -> 'XAbortChannel_baca0bc4':
        """
        creates a command channel to be used to asynchronously abort a command.
        """
    def disableExtension(self, extension: 'XPackage_cb1f0c4d', xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> None:
        """
        disable an extension.
        
        If the extension is not from the user repository then an IllegalArgumentException is thrown.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def enableExtension(self, extension: 'XPackage_cb1f0c4d', xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> None:
        """
        enable an extension.
        
        If the extension is not from the user repository then an IllegalArgumentException is thrown.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getAllExtensions(self, xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> 'typing.Tuple[typing.Tuple[XPackage_cb1f0c4d, ...], ...]':
        """
        returns a sequence containing all installed extensions.
        
        The members of the returned sequence correspond to an extension with a particular extension identifier. The members are also sequences which contain as many elements as there are repositories. Those are ordered according to the priority of the repository. That is, the first member is the extension from the user repository, the second is from the shared repository and the last is from the bundled repository.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getDeployedExtension(self, repository: str, identifier: str, fileName: str, xCmdEnv: 'XCommandEnvironment_fb330dee') -> 'XPackage_cb1f0c4d':
        """
        gets an installed extensions.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getDeployedExtensions(self, repository: str, xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> 'typing.Tuple[XPackage_cb1f0c4d, ...]':
        """
        gets all currently installed extensions, including disabled user extensions.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getExtensionsWithSameIdentifier(self, identifier: str, fileName: str, xCmdEnv: 'XCommandEnvironment_fb330dee') -> 'typing.Tuple[XPackage_cb1f0c4d, ...]':
        """
        gets all extensions with the same identifier from all repositories.
        
        The extension at the first position in the returned sequence represents the extension from the user repository. The next element is from the shared and the last one is from the bundled repository. If one repository does not contain this extension, then the respective element is a null reference.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getExtensionsWithUnacceptedLicenses(self, repository: str, xCmdEnv: 'XCommandEnvironment_fb330dee') -> 'typing.Tuple[XPackage_cb1f0c4d, ...]':
        """
        returns all extensions which are currently not in use because the user did not accept the license.
        
        The function will not return any object for the user repository, because a user extension will not be kept in the user repository if its license is declined. Only extensions which are registered at start-up of OOo, that is, shared and bundled extensions, can be returned.
        
        Extensions which allow the license to be suppressed, that is, it does not need to be displayed, and which are installed with the corresponding option, are also not returned.
        
        Extensions returned by these functions are not returned by XExtensionManager.getDeployedExtension() XExtensionManager.getDeployedExtensions() XExtensionManager.getAllExtensions() XExtensionManager.getExtensionsWithSameIdentifier()

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getSupportedPackageTypes(self) -> 'typing.Tuple[XPackageTypeInfo_3bc70f7b, ...]':
        """
        gets the supported XPackageTypeInfos.
        """
    def isReadOnlyRepository(self, repository: str) -> bool:
        """
        determines if the current user has write access to the extensions folder of the repository.
        """
    def reinstallDeployedExtensions(self, force: bool, repository: str, xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> None:
        """
        Expert feature: erases the underlying registry cache and reinstalls all previously added extensions.
        
        Please keep in mind that all registration status get lost.
        
        Please use this in case of suspected cache inconsistencies only.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def removeExtension(self, identifier: str, fileName: str, repository: str, xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> None:
        """
        removes an extension.

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def synchronize(self, xAbortChannel: 'XAbortChannel_baca0bc4', xCmdEnv: 'XCommandEnvironment_fb330dee') -> bool:
        """
        synchronizes the extension database with the contents of the extensions folder of shared and bundled extensions.
        
        Added extensions will be added to the database and removed extensions will be removed from the database. The active extensions are determined. That is, shared or bundled extensions are not necessarily registered (XPackage.registerPackage()).

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.ucb.CommandAbortedException: ``CommandAbortedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal
from .x_paragraph_append import XParagraphAppend as XParagraphAppend_e2930d13
from .x_text import XText as XText_690408ca
from .x_text_portion_append import XTextPortionAppend as XTextPortionAppend_170e0d

class XTextAppend(XParagraphAppend_e2930d13, XText_690408ca, XTextPortionAppend_170e0d):
    """
    is a meta-interface for manipulating and inserting text.

    See Also:
        `API XTextAppend <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XTextAppend.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.text.XTextAppend']





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xml.dom
from typing_extensions import Literal
import typing
from .x_node import XNode as XNode_83fb09a5
if typing.TYPE_CHECKING:
    from .x_named_node_map import XNamedNodeMap as XNamedNodeMap_de600ca8

class XDocumentType(XNode_83fb09a5):
    """

    See Also:
        `API XDocumentType <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XDocumentType.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.dom.XDocumentType']

    def getEntities(self) -> 'XNamedNodeMap_de600ca8':
        """
        A NamedNodeMap containing the general entities, both external and internal, declared in the DTD.
        """
    def getInternalSubset(self) -> str:
        """
        The internal subset as a string, or null if there is none.
        """
    def getName(self) -> str:
        """
        The name of DTD; i.e., the name immediately following the DOCTYPE keyword.
        """
    def getNotations(self) -> 'XNamedNodeMap_de600ca8':
        """
        A NamedNodeMap containing the notations declared in the DTD.
        """
    def getPublicId(self) -> str:
        """
        The public identifier of the external subset.
        """
    def getSystemId(self) -> str:
        """
        The system identifier of the external subset.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.embed
from typing_extensions import Literal
"""
Const

The constant set contains possible modes to open an element.

The modes can be combined by \"or\" operation. ElementModes.READ and ElementModes.WRITE are base modes. A result mode must include one of base modes.

See Also:
    `API ElementModes <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1embed_1_1ElementModes.html>`_
"""
READ: Literal[1]
"""
specifies opening of an element for reading.
"""
SEEKABLE: Literal[2]
"""
specifies opening of a seekable element.

This mode is ignored for Storage elements. This flag makes sense only in combination with ElementModes.READ and/or ElementModes.WRITE.
"""
SEEKABLEREAD: Literal[3]
"""
specifies opening of a seekable element for reading.

This is just a combination of the previous two values. For storages it is the same as ElementModes.READ.
"""
WRITE: Literal[4]
"""
specifies opening of an element for writing.
"""
READWRITE: Literal[7]
"""
specifies opening of an element for reading and writing.

For a stream element is also specifies that it must be seekable.
"""
TRUNCATE: Literal[8]
"""
lets the document be truncated immediately after opening.

This flag makes sense only in combination with ElementModes.WRITE.
"""
NOCREATE: Literal[16]
"""
restricts creation of a new element on opening in case a requested one does not exist.

This flag makes sense only in combination with ElementModes.WRITE.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal
"""
Const

These constants are used to specify which information about a template is displayed in a field.

See Also:
    `API TemplateDisplayFormat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1TemplateDisplayFormat.html>`_
"""
FULL: Literal[0]
PATH: Literal[1]
NAME: Literal[2]
"""
Only the file name, without file extension, of the template file will be displayed.
"""
NAME_AND_EXT: Literal[3]
"""
The file name and the file extension of the template file will be displayed.
"""
AREA: Literal[4]
"""
The name of the template area is displayed.
"""
TITLE: Literal[5]
"""
The title of the template file is displayed.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.document
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .undo_manager_event import UndoManagerEvent as UndoManagerEvent_1c2d0eba
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XUndoManagerListener(XEventListener_c7230c4a):
    """
    implemented by components which want to be notified of changes in the Undo/Redo stacks of an Undo manager.
    
    **since**
    
        OOo 3.4

    See Also:
        `API XUndoManagerListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XUndoManagerListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.document.XUndoManagerListener']

    def actionRedone(self, iEvent: 'UndoManagerEvent_1c2d0eba') -> None:
        """
        is called when the top-most action of the Redo stack has been re-applied.
        """
    def actionUndone(self, iEvent: 'UndoManagerEvent_1c2d0eba') -> None:
        """
        is called when the top-most action of the undo stack has been undone.
        """
    def allActionsCleared(self, iEvent: 'EventObject_a3d70b03') -> None:
        """
        is called when both the Undo and the Redo stack have been cleared from all Undo actions.
        """
    def cancelledContext(self, iEvent: 'UndoManagerEvent_1c2d0eba') -> None:
        """
        is called when an Undo context has been left, but no actions have been added within this context.
        
        In such a case, the context which has just been left will not contribute to the undo stack, but instead be silently removed. Consequently, the UndoManagerEvent.UndoActionTitle is empty.
        """
    def enteredContext(self, iEvent: 'UndoManagerEvent_1c2d0eba') -> None:
        """
        is called when a new Undo context has been entered.
        
        UndoManagerEvent.UndoActionTitle carries the title of the Undo context, and UndoManagerEvent.UndoContextDepth the number of open Undo contexts, including the one just entered.
        """
    def enteredHiddenContext(self, iEvent: 'UndoManagerEvent_1c2d0eba') -> None:
        """
        is called when a new hidden Undo context has been entered.
        
        UndoManagerEvent.UndoActionTitle carries the title of the Undo context, and UndoManagerEvent.UndoContextDepth the number of open Undo contexts, including the one just entered.
        """
    def leftContext(self, iEvent: 'UndoManagerEvent_1c2d0eba') -> None:
        """
        is called when an Undo context has been left.
        
        UndoManagerEvent.UndoActionTitle carries the title of the Undo context, and UndoManagerEvent.UndoContextDepth the number of open Undo contexts, excluding the one just left.
        """
    def leftHiddenContext(self, iEvent: 'UndoManagerEvent_1c2d0eba') -> None:
        """
        is called when a hidden Undo context has been left.
        
        UndoManagerEvent.UndoActionTitle is empty, as hidden Undo contexts don't have a title.
        """
    def redoActionsCleared(self, iEvent: 'EventObject_a3d70b03') -> None:
        """
        is called when the Redo stack has been cleared.
        """
    def resetAll(self, iEvent: 'EventObject_a3d70b03') -> None:
        """
        called when the complete undo manager has been reset
        """
    def undoActionAdded(self, iEvent: 'UndoManagerEvent_1c2d0eba') -> None:
        """
        is called when an undo action is added to the undo stack.
        
        Note that the action must not necessarily be the new top element of the stack: In case there's an open Undo context, UndoManagerEvent.UndoContextDepth will be greater 0, and the newly added action will be subordinate of the context action.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..lang.locale import Locale as Locale_70d308fa
from .search_algorithms import SearchAlgorithms as SearchAlgorithms_e2c00d36


class SearchOptions(object):
    """
    Struct Class


    See Also:
        `API SearchOptions <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1SearchOptions.html>`_
    """
    typeName: Literal['com.sun.star.util.SearchOptions']

    def __init__(self, algorithmType: typing.Optional[SearchAlgorithms_e2c00d36] = ..., searchFlag: typing.Optional[int] = ..., searchString: typing.Optional[str] = ..., replaceString: typing.Optional[str] = ..., Locale: typing.Optional[Locale_70d308fa] = ..., changedChars: typing.Optional[int] = ..., deletedChars: typing.Optional[int] = ..., insertedChars: typing.Optional[int] = ..., transliterateFlags: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            algorithmType (SearchAlgorithms, optional): algorithmType value.
            searchFlag (int, optional): searchFlag value.
            searchString (str, optional): searchString value.
            replaceString (str, optional): replaceString value.
            Locale (Locale, optional): Locale value.
            changedChars (int, optional): changedChars value.
            deletedChars (int, optional): deletedChars value.
            insertedChars (int, optional): insertedChars value.
            transliterateFlags (int, optional): transliterateFlags value.
        """


    @property
    def algorithmType(self) -> SearchAlgorithms_e2c00d36:
        """
        search type
        """


    @property
    def searchFlag(self) -> int:
        """
        some flags - can be mixed
        """


    @property
    def searchString(self) -> str:
        """
        The text or pattern to be searched.
        """


    @property
    def replaceString(self) -> str:
        """
        The replacement text (is for optional replacing - SearchOption is only the data container for it)
        """


    @property
    def Locale(self) -> Locale_70d308fa:
        """
        The locale for case insensitive search.
        """


    @property
    def changedChars(self) -> int:
        """
        This many characters can be different (as a replacement) between the found word and the search pattern in a \"Weighted Levenshtein
        Distance\" search.
        """


    @property
    def deletedChars(self) -> int:
        """
        This many characters can be missing in the found word in a \"Weighted Levenshtein Distance\" search.
        """


    @property
    def insertedChars(self) -> int:
        """
        This many characters can be additional in the found word in a \"Weighted Levenshtein Distance\" search.
        """


    @property
    def transliterateFlags(self) -> int:
        """
        Flags for the transliteration.
        
        Same meaning as the enum of com.sun.star.i18n.TransliterationModules
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .panose import Panose as Panose_a6bc0b2c
from ..util.tri_state import TriState as TriState_85af09f6


class FontInfo(object):
    """
    Struct Class

    This structure provides information about a specific font.
    
    **since**
    
        OOo 2.0

    See Also:
        `API FontInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1FontInfo.html>`_
    """
    typeName: Literal['com.sun.star.rendering.FontInfo']

    def __init__(self, FontDescription: typing.Optional[Panose_a6bc0b2c] = ..., FamilyName: typing.Optional[str] = ..., StyleName: typing.Optional[str] = ..., UnicodeRanges0: typing.Optional[int] = ..., UnicodeRanges1: typing.Optional[int] = ..., UnicodeRanges2: typing.Optional[int] = ..., UnicodeRanges3: typing.Optional[int] = ..., IsSymbolFont: typing.Optional[TriState_85af09f6] = ..., IsVertical: typing.Optional[TriState_85af09f6] = ...) -> None:
        """
        Constructor

        Arguments:
            FontDescription (Panose, optional): FontDescription value.
            FamilyName (str, optional): FamilyName value.
            StyleName (str, optional): StyleName value.
            UnicodeRanges0 (int, optional): UnicodeRanges0 value.
            UnicodeRanges1 (int, optional): UnicodeRanges1 value.
            UnicodeRanges2 (int, optional): UnicodeRanges2 value.
            UnicodeRanges3 (int, optional): UnicodeRanges3 value.
            IsSymbolFont (TriState, optional): IsSymbolFont value.
            IsVertical (TriState, optional): IsVertical value.
        """


    @property
    def FontDescription(self) -> Panose_a6bc0b2c:
        """
        The PANOSE font classification.
        
        TODO: Document semantics in Panose.idl
        """


    @property
    def FamilyName(self) -> str:
        """
        The name of the font family.
        
        The family name is the one normally associated to a font, such as Times New Roman, Thorndale, Andale or Arial.
        
        Note: outlined fonts are now specified with \"outline\" as part of the family name.
        """


    @property
    def StyleName(self) -> str:
        """
        The name of the specific font style within its family.
        
        For example, oblique, italic, or narrow.
        """


    @property
    def UnicodeRanges0(self) -> int:
        """
        This value specifies which Unicode ranges are supported by this font.
        
        This is to be interpreted as a split-up 128-bit value, see Adobe's OpenType specification for the specific meaning of each bit. UnicodeRanges0 contains the least significant bits, UnicodeRanges3 the most significant ones.
        
        const int128 UNICODE_RANGE_BASIC_LATIN = 1; const int128 UNICODE_RANGE_LATIN_SUPPLEMENT = 2; const int128 UNICODE_RANGE_LATIN_EXTENDED_A = 4; const int128 UNICODE_RANGE_LATIN_EXTENDED_B = 4; ... const int128 UNICODE_RANGE_MASK_LATIN = 1; const int128 UNICODE_RANGE_MASK_CJK = (31<<48) + (3<<55) + (1<<59); const int128 UNICODE_RANGE_MASK_CTL = (1<<11) + (1<<13) + (0x3FFF<<15) + (0x0FFF<<70);
        """


    @property
    def UnicodeRanges1(self) -> int:
        ...


    @property
    def UnicodeRanges2(self) -> int:
        ...


    @property
    def UnicodeRanges3(self) -> int:
        ...


    @property
    def IsSymbolFont(self) -> TriState_85af09f6:
        """
        Specifies whether the font is a symbol font.
        
        If yes, text written in this symbol font does not have a specified meaning.
        """


    @property
    def IsVertical(self) -> TriState_85af09f6:
        """
        Set to true, if the font is usable for vertical text output.
        
        Vertical fonts have subtle differences to horizontal ones, e.g. rotated or differently shaped glyphs, or special rotated versions of normally upright glyphs (e.g. brackets).
        """


